@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class KategoriTk:
-    kategori_tk_id: str
+    kategori_tk_id: int
     nama: str
     create_date: datetime
     last_update: datetime
