@@ -1,9 +1,10 @@
 from datetime import datetime
+from typing import Optional
 
-from dapodik.base import dataclass, freeze
+import attr
 
 
-@dataclass
+@attr.dataclass
 class TanahLongitudinal:
     id_tanah: str
     njop: float
@@ -12,8 +13,8 @@ class TanahLongitudinal:
     id_tanah_str: str = ""
     tanah_longitudinal_id: str = "Admin.model.TanahLongitudinal-2"
     tanah_longitudinal_id_str: str = ""
-    create_date: datetime = freeze(default=None)
-    last_update: datetime = freeze(default=None)
-    soft_delete: str = freeze(default=None)
-    last_sync: datetime = freeze(default=None)
-    updater_id: str = freeze(default=None)
+    create_date: Optional[datetime] = None
+    last_update: Optional[datetime] = None
+    soft_delete: Optional[str] = None
+    last_sync: Optional[datetime] = None
+    updater_id: Optional[str] = None
